@@ -396,7 +396,7 @@ fn format_directive<'entry>(
     // NOTE ON QUOTING:
     // GNU find's man page claims that several directives that print names (like
     // %f) are quoted like ls; however, I could not reproduce this at all in
-    // pratice, thus the set of rules is undoubtedly very different (if this is
+    // practice, thus the set of rules is undoubtedly very different (if this is
     // still done at all).
 
     let res: Cow<'entry, str> = match directive {
@@ -463,11 +463,13 @@ fn format_directive<'entry>(
         #[cfg(unix)]
         FormatDirective::Filesystem => {
             let dev_id = meta()?.dev().to_string();
-            uucore::fsext::read_fs_list()
+            let fs_list =
+                uucore::fsext::read_fs_list().expect("Could not find the filesystem info");
+            fs_list
                 .into_iter()
                 .find(|fs| fs.dev_id == dev_id)
                 .map(|fs| fs.fs_type)
-                .unwrap_or_else(|| "".to_owned())
+                .unwrap_or_else(String::new)
                 .into()
         }
 
@@ -946,52 +948,70 @@ mod tests {
         #[cfg(unix)]
         {
             if let Err(e) = symlink("abbbc", "test_data/links/link-f") {
-                if e.kind() != ErrorKind::AlreadyExists {
-                    panic!("Failed to create sym link: {:?}", e);
-                }
+                assert!(
+                    e.kind() == ErrorKind::AlreadyExists,
+                    "Failed to create sym link: {:?}",
+                    e
+                );
             }
             if let Err(e) = symlink("subdir", "test_data/links/link-d") {
-                if e.kind() != ErrorKind::AlreadyExists {
-                    panic!("Failed to create sym link: {:?}", e);
-                }
+                assert!(
+                    e.kind() == ErrorKind::AlreadyExists,
+                    "Failed to create sym link: {:?}",
+                    e
+                );
             }
             if let Err(e) = symlink("missing", "test_data/links/link-missing") {
-                if e.kind() != ErrorKind::AlreadyExists {
-                    panic!("Failed to create sym link: {:?}", e);
-                }
+                assert!(
+                    e.kind() == ErrorKind::AlreadyExists,
+                    "Failed to create sym link: {:?}",
+                    e
+                );
             }
             if let Err(e) = symlink("abbbc/x", "test_data/links/link-notdir") {
-                if e.kind() != ErrorKind::AlreadyExists {
-                    panic!("Failed to create sym link: {:?}", e);
-                }
+                assert!(
+                    e.kind() == ErrorKind::AlreadyExists,
+                    "Failed to create sym link: {:?}",
+                    e
+                );
             }
             if let Err(e) = symlink("link-loop", "test_data/links/link-loop") {
-                if e.kind() != ErrorKind::AlreadyExists {
-                    panic!("Failed to create sym link: {:?}", e);
-                }
+                assert!(
+                    e.kind() == ErrorKind::AlreadyExists,
+                    "Failed to create sym link: {:?}",
+                    e
+                );
             }
         }
         #[cfg(windows)]
         {
             if let Err(e) = symlink_file("abbbc", "test_data/links/link-f") {
-                if e.kind() != ErrorKind::AlreadyExists {
-                    panic!("Failed to create sym link: {:?}", e);
-                }
+                assert!(
+                    e.kind() == ErrorKind::AlreadyExists,
+                    "Failed to create sym link: {:?}",
+                    e
+                );
             }
             if let Err(e) = symlink_dir("subdir", "test_data/links/link-d") {
-                if e.kind() != ErrorKind::AlreadyExists {
-                    panic!("Failed to create sym link: {:?}", e);
-                }
+                assert!(
+                    e.kind() == ErrorKind::AlreadyExists,
+                    "Failed to create sym link: {:?}",
+                    e
+                );
             }
             if let Err(e) = symlink_file("missing", "test_data/links/link-missing") {
-                if e.kind() != ErrorKind::AlreadyExists {
-                    panic!("Failed to create sym link: {:?}", e);
-                }
+                assert!(
+                    e.kind() == ErrorKind::AlreadyExists,
+                    "Failed to create sym link: {:?}",
+                    e
+                );
             }
             if let Err(e) = symlink_file("abbbc/x", "test_data/links/link-notdir") {
-                if e.kind() != ErrorKind::AlreadyExists {
-                    panic!("Failed to create sym link: {:?}", e);
-                }
+                assert!(
+                    e.kind() == ErrorKind::AlreadyExists,
+                    "Failed to create sym link: {:?}",
+                    e
+                );
             }
         }
 
