@@ -338,15 +338,19 @@ mod tests {
     fn create_file_link() {
         #[cfg(unix)]
         if let Err(e) = symlink("abbbc", "test_data/links/link-f") {
-            if e.kind() != ErrorKind::AlreadyExists {
-                panic!("Failed to create sym link: {:?}", e);
-            }
+            assert!(
+                e.kind() == ErrorKind::AlreadyExists,
+                "Failed to create sym link: {:?}",
+                e
+            );
         }
         #[cfg(windows)]
         if let Err(e) = symlink_file("abbbc", "test_data/links/link-f") {
-            if e.kind() != ErrorKind::AlreadyExists {
-                panic!("Failed to create sym link: {:?}", e);
-            }
+            assert!(
+                e.kind() == ErrorKind::AlreadyExists,
+                "Failed to create sym link: {:?}",
+                e
+            );
         }
     }
 
